@@ -1,12 +1,13 @@
 package TestConfig;
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(Str);
 use File::Spec;
 extends 'Config::GitLike';
 
 has 'tmpdir' => (
     is => 'rw',
     required => 1,
-    isa => 'Str',
+    isa => Str,
 );
 
 # override these methods so:
@@ -57,7 +58,7 @@ sub burp {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
